@@ -1,25 +1,25 @@
 /*
-* Copyright 2016 Kai Uwe Broulik <kde@privat.broulik.de>
-*
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License as
-* published by the Free Software Foundation; either version 2 of
-* the License or (at your option) version 3 or any later version
-* accepted by the membership of KDE e.V. (or its successor approved
-* by the membership of KDE e.V.), which shall act as a proxy
-* defined in Section 14 of version 3 of the license.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+ * Copyright 2016 Kai Uwe Broulik <kde@privat.broulik.de>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License or (at your option) version 3 or any later version
+ * accepted by the membership of KDE e.V. (or its successor approved
+ * by the membership of KDE e.V.), which shall act as a proxy
+ * defined in Section 14 of version 3 of the license.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
-#include <QCoreApplication>
 #include <QCommandLineParser>
+#include <QCoreApplication>
 #include <QDBusConnection>
 #include <QDBusMessage>
 #include <QTimer>
@@ -34,7 +34,8 @@ int main(int argc, char *argv[])
     QCoreApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("kbroadcastnotification");
 
-    KAboutData aboutData(QStringLiteral("kbroadcastnotification"), i18n("Broadcast Notifications"),
+    KAboutData aboutData(QStringLiteral("kbroadcastnotification"),
+                         i18n("Broadcast Notifications"),
                          QLatin1String(PROJECT_VERSION),
                          i18n("A tool that emits a notification for all users by sending it on the system DBus"),
                          KAboutLicense::GPL,
@@ -44,13 +45,18 @@ int main(int argc, char *argv[])
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
 
-    QCommandLineOption applicationNameOption(QStringLiteral("application"), i18n("Name of the application that should be associated with this notification"), QStringLiteral("application"));
+    QCommandLineOption applicationNameOption(QStringLiteral("application"),
+                                             i18n("Name of the application that should be associated with this notification"),
+                                             QStringLiteral("application"));
     parser.addOption(applicationNameOption);
     QCommandLineOption summaryOption(QStringLiteral("summary"), i18n("A brief one-line summary of the notification"), QStringLiteral("summary"));
     parser.addOption(summaryOption);
     QCommandLineOption iconOption(QStringLiteral("icon"), i18n("Icon for the notification"), QStringLiteral("icon"));
     parser.addOption(iconOption);
-    QCommandLineOption uidsOption(QStringLiteral("uids"), i18n("A comma-separated list of user IDs this notification should be sent to. If omitted, the notification will be sent to all users."), QStringLiteral("uids"));
+    QCommandLineOption uidsOption(
+        QStringLiteral("uids"),
+        i18n("A comma-separated list of user IDs this notification should be sent to. If omitted, the notification will be sent to all users."),
+        QStringLiteral("uids"));
     parser.addOption(uidsOption);
     QCommandLineOption timeoutOption(QStringLiteral("timeout"), i18n("Timeout for the notification"), QStringLiteral("timeout"));
     parser.addOption(timeoutOption);
@@ -74,11 +80,7 @@ int main(int argc, char *argv[])
     }
 
     if (parser.isSet(uidsOption)) {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        const QStringList &uids = parser.value(uidsOption).split(QLatin1Char(','), QString::SkipEmptyParts);
-#else
         const QStringList &uids = parser.value(uidsOption).split(QLatin1Char(','), Qt::SkipEmptyParts);
-#endif
         if (!uids.isEmpty()) {
             properties.insert(QStringLiteral("uids"), uids);
         }
